@@ -1,5 +1,6 @@
 """EUMETSAT Data Access Client"""
 from __future__ import annotations
+from .__version__ import __title__, __documentation__, __version__  # noqa
 
 import argparse
 import os
@@ -35,9 +36,12 @@ def get_config_dir() -> pathlib.Path:
     return pathlib.Path(os.getenv("EUMDAC_CONFIG_DIR", (pathlib.Path.home() / ".eumdac")))
 
 
+def get_credentials_path() -> pathlib.Path:
+    return get_config_dir() / "credentials"
+
+
 def load_credentials(parser: argparse.ArgumentParser) -> Iterable[str]:
-    config_dir = get_config_dir()
-    credentials_path = config_dir / "credentials"
+    credentials_path = get_credentials_path()
     try:
         content = credentials_path.read_text()
     except FileNotFoundError:
@@ -59,7 +63,7 @@ class SetCredentials(argparse.Action):
         token = eumdac.AccessToken(values)  # type: ignore[arg-type]
         config_dir = get_config_dir()
         config_dir.mkdir(exist_ok=True)
-        credentials_path = config_dir / "credentials"
+        credentials_path = get_credentials_path()
         credentials_path.touch(mode=(stat.S_IRUSR | stat.S_IWUSR))
 
         try:
@@ -79,7 +83,7 @@ class SetCredentials(argparse.Action):
                     "The provided credentials are not valid. Get your personal credentials at https://api.eumetsat.int/api-key",
                 )
             else:
-                print(f"Token API responses with a {e.response.status_code} error.")
+                report_request_error(e.response)
 
         parser.exit()
 
@@ -134,9 +138,10 @@ def describe(args: argparse.Namespace) -> None:
             else f"{product.sensing_end.isoformat(timespec='milliseconds')}Z",
             "Size": f"{product.size} KB",
         }
-        print(f"{product.collection} - {product}")
-        lines = [f"{key}: {value}" for key, value in attributes.items()]
-        print(os.linesep.join(lines))
+        lines = [f"{product.collection} - {product}"] + [
+            f"{key}: {value}" for key, value in attributes.items()
+        ]
+        print("\n".join(lines))
 
 
 def search(args: argparse.Namespace) -> None:
@@ -151,6 +156,11 @@ def search(args: argparse.Namespace) -> None:
             "geo": args.geo,
             "sat": args.sat,
             "sort": args.sort,
+            "cycle": args.cycle,
+            "orbit": args.orbit,
+            "relorbit": args.relorbit,
+            "title": args.filename,
+            "timeliness": args.timeliness,
         }
         query = {key: value for key, value in _query.items() if value is not None}
         limit = args.limit
@@ -214,21 +224,41 @@ def download(args: argparse.Namespace) -> None:
     datastore = eumdac.DataStore(token)
     collection_id = args.collection
 
-    def download_product(product: Product) -> None:
+    def download_product(product: Product, args: argparse.Namespace) -> None:
         with product.open(entry=entry) as fsrc:
-            output = args.output_dir / fsrc.name
-            if output.is_file():
-                print(f"Skip {fsrc.name} it already exists")
+            if args.entry is None:
+                output = args.output_dir / fsrc.name
+                if output.is_file():
+                    print(f"Skip {fsrc.name} it already exists")
+                else:
+                    print(f"Downloading {fsrc.name}")
+                    tmp = args.output_dir / (fsrc.name + ".tmp")
+                    with tmp.open(mode="wb") as fdst:
+                        # note: currently, there is no content-length header
+                        # in the data store http response, so it is not simple to
+                        # build a progress bar. In case it is added in future,
+                        # just check fsrc.getheader("Content-Length")
+                        shutil.copyfileobj(fsrc, fdst)
+                    tmp.rename(output)
             else:
-                print(f"Downloading {fsrc.name}")
-                tmp = args.output_dir / (fsrc.name + ".tmp")
-                with tmp.open(mode="wb") as fdst:
-                    # note: currently, there is no content-length header
-                    # in the data store http response, so it is not simple to
-                    # build a progress bar. In case it is added in future,
-                    # just check fsrc.getheader("Content-Length")
-                    shutil.copyfileobj(fsrc, fdst)
-                tmp.rename(output)
+                # If --entry is used, a directory for each product will
+                # be generated, in which the desired files will be downloaded.
+                path = pathlib.Path(args.output_dir, str(product_id))
+                if not os.path.exists(path):
+                    os.mkdir(path)
+                output = path / fsrc.name
+                if output.is_file():
+                    print(f"Skip {str(product_id)}/{fsrc.name} it already exists")
+                else:
+                    print(f"Downloading {str(product_id)}/{fsrc.name}")
+                    tmp = path / (fsrc.name + ".tmp")
+                    with tmp.open(mode="wb") as fdst:
+                        # note: currently, there is no content-length header
+                        # in the data store http response, so it is not simple to
+                        # build a progress bar. In case it is added in future,
+                        # just check fsrc.getheader("Content-Length")
+                        shutil.copyfileobj(fsrc, fdst)
+                    tmp.rename(output)
 
     if not args.product:
         if not args.time_range:
@@ -236,7 +266,11 @@ def download(args: argparse.Namespace) -> None:
         start, end = args.time_range
         collection = datastore.get_collection(collection_id)
         args.product = [str(product) for product in collection.search(dtstart=start, dtend=end)]
-    print(f"Output directory: {args.output_dir}")
+
+    # Create specified output directory and report
+    os.makedirs(args.output_dir, exist_ok=True)
+    print(f"Output directory: {os.path.abspath(args.output_dir)}")
+
     for product_id in args.product:
         try:
             product = datastore.get_product(collection_id, product_id)
@@ -251,14 +285,14 @@ def download(args: argparse.Namespace) -> None:
                 except requests.exceptions.HTTPError:
                     time.sleep(2000)
                     product = datastore.get_product(collection_id, product_id)
-        if args.file_pattern is None:
-            enties = [None]
+        if args.entry is None:
+            entries = [None]
         else:
-            matches = (fnmatch.filter(product.entries, pattern) for pattern in args.file_pattern)
-            enties = sum(matches, [])
-        for entry in enties:
+            matches = (fnmatch.filter(product.entries, pattern) for pattern in args.entry)
+            entries = sum(matches, [])
+        for entry in entries:
             try:
-                download_product(product)
+                download_product(product, args)
             except requests.exceptions.HTTPError as exception:
                 if exception.response.status_code >= 400 and exception.response.status_code < 500:
                     print("Product ID doesn't exist. See below:")
@@ -266,10 +300,10 @@ def download(args: argparse.Namespace) -> None:
                 elif exception.response.status_code >= 500:
                     try:
                         time.sleep(2000)
-                        download_product(product)
+                        download_product(product, args)
                     except requests.exceptions.HTTPError:
                         time.sleep(2000)
-                        download_product(product)
+                        download_product(product, args)
 
 
 def subscribe_list_subscriptions(args: argparse.Namespace) -> None:
@@ -588,7 +622,14 @@ def tailor_download(args: argparse.Namespace) -> None:
     # for customisation_id in customisation_ids:  # type: ignore[union-attr]
     customisation_id = args.job_id
     url = "https://api.eumetsat.int/epcs/customisations/" + customisation_id
-    response = requests.get(url, headers={"Authorization": "Bearer {}".format(token)})
+    response = requests.get(
+        url,
+        headers={
+            "Authorization": "Bearer {}".format(token),
+            "referer": __documentation__,
+            "User-Agent": str(__title__ + "/" + __version__),
+        },
+    )
     if response.status_code == 200:
         results = response.json()[customisation_id]["output_products"]
 
@@ -603,7 +644,14 @@ def tailor_download(args: argparse.Namespace) -> None:
         for result in results:
             print("Downloading " + os.path.basename(result))
             url = "https://api.eumetsat.int/epcs/download?path=" + result
-            response = requests.get(url, headers={"Authorization": "Bearer {}".format(token)})
+            response = requests.get(
+                url,
+                headers={
+                    "Authorization": "Bearer {}".format(token),
+                    "referer": __documentation__,
+                    "User-Agent": str(__title__ + "/" + __version__),
+                },
+            )
             output = args.output_dir
             if response.status_code == 200:
                 product_path = os.path.join(output, os.path.basename(result))
@@ -640,7 +688,7 @@ def report_request_error(response: requests.Response, message: Optional[str] = N
     print(f"{response.status_code} - {response.text}")
 
 
-class TailorHelpAction(argparse.Action):
+class PrintHelpAction(argparse.Action):
     def __call__(self, parser: argparse.ArgumentParser, *args: Any, **kwargs: Any) -> None:
         # Print the help if the command has 2 args,
         # meaning it's just $ eumdac tailor
@@ -728,6 +776,33 @@ def cli(command_line: Optional[Sequence[str]] = None) -> None:
         help="filter by geometry, a custom geomtery in a EPSG:4326 decimal degrees.",
         dest="geo",
     )
+    parser_search.add_argument(
+        "--cycle",
+        help="filter by cycle number, must be a positive integer.",
+        dest="cycle",
+        type=int,
+    )
+    parser_search.add_argument(
+        "--orbit",
+        help="filter by orbit number, must be a positive integer.",
+        dest="orbit",
+        type=int,
+    )
+    parser_search.add_argument(
+        "--relorbit",
+        help="filter by relative orbit number, must be a positive integer.",
+        dest="relorbit",
+        type=int,
+    )
+    parser_search.add_argument(
+        "--filename",
+        help="Can be used to define a wildcard search on the product title (product identifier), use set notation as OR and space as AND operator between multiple search terms.",
+        dest="filename",
+        type=str,
+    )
+    parser_search.add_argument(
+        "--timeliness", help="filter by timeliness", dest="timeliness", choices=["NT", "NR", "ST"]
+    )
     parser_search.add_argument("--satellite", help="filter by satellite", dest="sat")
     parser_search.add_argument("--sort", help="sort results")
     parser_search.add_argument(
@@ -756,7 +831,7 @@ def cli(command_line: Optional[Sequence[str]] = None) -> None:
         default=pathlib.Path.cwd(),
     )
     parser_download.add_argument(
-        "--file-pattern", nargs="+", help="shell-style wildcard pattern(s) to filter product files"
+        "--entry", nargs="+", help="shell-style wildcard pattern(s) to filter product files"
     )
     parser_download.add_argument(
         "--time-range",
@@ -778,6 +853,9 @@ def cli(command_line: Optional[Sequence[str]] = None) -> None:
     parser_subscribe = subparsers.add_parser(
         "subscribe", help="subscribe a server for a collection"
     )
+    parser_subscribe.add_argument(
+        dest="print_help", nargs=0, action=PrintHelpAction, help=argparse.SUPPRESS
+    )
 
     subscribe_subparsers = parser_subscribe.add_subparsers(dest="subscribe-command")
 
@@ -826,7 +904,7 @@ def cli(command_line: Optional[Sequence[str]] = None) -> None:
         help="tailoring product(s) from collection",
     )
     parser_tailor.add_argument(
-        dest="print_help", nargs=0, action=TailorHelpAction, help=argparse.SUPPRESS
+        dest="print_help", nargs=0, action=PrintHelpAction, help=argparse.SUPPRESS
     )
     tailor_subparsers = parser_tailor.add_subparsers(dest="tailor-command")
 
