@@ -1,5 +1,6 @@
 """Module containing the Data Store Collection class."""
 from __future__ import annotations
+from .__version__ import __title__, __documentation__, __version__  # noqa
 
 import re
 from functools import total_ordering
@@ -107,7 +108,15 @@ class SearchResults:
         auth = self.collection.datastore.token.auth
         url = self.collection.datastore.urls.get("datastore", "search")
         if session is None:
-            response = requests.get(url, params=params, auth=auth)
+            response = requests.get(
+                url,
+                params=params,
+                auth=auth,
+                headers={
+                    "referer": __documentation__,
+                    "User-Agent": str(__title__ + "/" + __version__),
+                },
+            )
         else:
             response = session.get(url, params=params, auth=auth)
         response.raise_for_status()
@@ -174,7 +183,15 @@ class Collection:
             "datastore", "browse collection", vars={"collection_id": self._id}
         )
         auth = self.datastore.token.auth
-        response = requests.get(url, params={"format": "json"}, auth=auth)
+        response = requests.get(
+            url,
+            params={"format": "json"},
+            auth=auth,
+            headers={
+                "referer": __documentation__,
+                "User-Agent": str(__title__ + "/" + __version__),
+            },
+        )
         response.raise_for_status()
         geometry = response.json()["collection"]["geometry"]
         properties = response.json()["collection"]["properties"]
@@ -213,7 +230,14 @@ class Collection:
         self._ensure_properties()
         auth = self.datastore.token._access_token
         url = "https://api.eumetsat.int/epcs/0.1.0/products"
-        response = requests.get(url, headers={"Authorization": "Bearer {}".format(auth)})
+        response = requests.get(
+            url,
+            headers={
+                "Authorization": "Bearer {}".format(auth),
+                "referer": __documentation__,
+                "User-Agent": str(__title__ + "/" + __version__),
+            },
+        )
         api_response = json.loads(response.text)
 
         collection_ids = [i["pn_id"] for i in api_response["data"]]
@@ -249,7 +273,14 @@ class Collection:
             # a way to load collection specific options
             url = self.datastore.urls.get("datastore", "search")
             auth = self.datastore.token.auth
-            response = requests.get(url, auth=auth)
+            response = requests.get(
+                url,
+                auth=auth,
+                headers={
+                    "referer": __documentation__,
+                    "User-Agent": str(__title__ + "/" + __version__),
+                },
+            )
             response.raise_for_status()
             root = ElementTree.fromstring(response.text)
             (element,) = [
