@@ -1,5 +1,6 @@
 """Module contianing the customisation class"""
 from __future__ import annotations
+from .__version__ import __title__, __documentation__, __version__  # noqa
 
 import time
 from datetime import datetime
@@ -71,7 +72,14 @@ class Customisation:
             url = self.datatailor.urls.get(
                 "tailor", "customisation", vars={"customisation_id": self._id}
             )
-            response = requests.get(url, auth=self.datatailor.token.auth)
+            response = requests.get(
+                url,
+                auth=self.datatailor.token.auth,
+                headers={
+                    "referer": __documentation__,
+                    "User-Agent": str(__title__ + "/" + __version__),
+                },
+            )
             response.raise_for_status()
             self._properties = response.json()[self._id]
             self._last_update = now
@@ -125,7 +133,14 @@ class Customisation:
         url = self.datatailor.urls.get(
             "tailor", "customisation log", vars={"customisation_id": self._id}
         )
-        response = requests.get(url, auth=self.datatailor.token.auth)
+        response = requests.get(
+            url,
+            auth=self.datatailor.token.auth,
+            headers={
+                "referer": __documentation__,
+                "User-Agent": str(__title__ + "/" + __version__),
+            },
+        )
         response.raise_for_status()
         return response.json()["log_content"]
 
@@ -138,7 +153,16 @@ class Customisation:
         url = self.datatailor.urls.get("tailor", "download")
         auth = self.datatailor.token.auth
         params = {"path": output}
-        with requests.get(url, auth=auth, params=params, stream=True) as response:
+        with requests.get(
+            url,
+            auth=auth,
+            params=params,
+            stream=True,
+            headers={
+                "referer": __documentation__,
+                "User-Agent": str(__title__ + "/" + __version__),
+            },
+        ) as response:
             response.raise_for_status()
             response.raw.name = output.split("/")[-1]
             response.raw.decode_content = True
