@@ -1,4 +1,5 @@
 from __future__ import annotations
+from .__version__ import __title__, __documentation__, __version__  # noqa
 
 import time
 
@@ -48,7 +49,14 @@ class Subscription:
             url = self.datastore.urls.get(
                 "datastore", "subscription", vars={"subscription_id": self._id}
             )
-            response = requests.get(url, auth=self.datastore.token.auth)
+            response = requests.get(
+                url,
+                auth=self.datastore.token.auth,
+                headers={
+                    "referer": __documentation__,
+                    "User-Agent": str(__title__ + "/" + __version__),
+                },
+            )
             response.raise_for_status()
             self._properties = response.json()
             self._last_update = now
